@@ -1,13 +1,16 @@
-import trio
+import errno
 import os
 import socket
-import errno
+
+import trio
 
 bad_socket = socket.socket()
 
+
 class BlockingReadTimeoutError(Exception):
     pass
 
+
 async def blocking_read_with_timeout(fd, count, timeout):
     print("reading from fd", fd)
     cancel_requested = False
@@ -29,11 +32,11 @@ async def blocking_read_with_timeout(fd, count, timeout):
         async with trio.open_nursery() as nursery:
             nursery.start_soon(kill_it_after_timeout, new_fd)
             try:
-                data = await trio.run_sync_in_worker_thread(os.read, new_fd, count)
+                data = await trio.to_thread.run_sync(os.read, new_fd, count)
             except OSError as exc:
                 if cancel_requested and exc.errno == errno.ENOTCONN:
                     # Call was successfully cancelled. In a real version we'd
-                    # integrate properly with trio's cancellation tools; here
+                    # integrate properly with Trio's cancellation tools; here
                     # we'll just raise an arbitrary error.
                     raise BlockingReadTimeoutError from None
             print("got", data)
@@ -42,4 +45,5 @@ async def blocking_read_with_timeout(fd, count, timeout):
     finally:
         os.close(new_fd)
 
+
 trio.run(blocking_read_with_timeout, 0, 10, 2)
