@@ -1,5 +1,9 @@
+import signal
+
+import gsm
 import trio
 
+
 class GracefulShutdownManager:
     def __init__(self):
         self._shutting_down = False
@@ -21,6 +25,7 @@ class GracefulShutdownManager:
     def shutting_down(self):
         return self._shutting_down
 
+
 # Code can check gsm.shutting_down occasionally at appropriate points to see
 # if it should exit.
 #
@@ -31,13 +36,15 @@ async def stream_handler(stream):
     while True:
         with gsm.cancel_on_graceful_shutdown():
             data = await stream.receive_some()
+            print(f"{data = }")
         if gsm.shutting_down:
             break
 
+
 # To trigger the shutdown:
 async def listen_for_shutdown_signals():
     with trio.open_signal_receiver(signal.SIGINT, signal.SIGTERM) as signal_aiter:
-        async for sig in signal_aiter:
+        async for _sig in signal_aiter:
             gsm.start_shutdown()
             break
         # TODO: it'd be nice to have some logic like "if we get another
